
// VagueResponses.java
// Andrew Davison, July 2005, ad@fivedots.coe.psu.ac.th

/* Load in a text file of 'vague' responses -- text lines
   which are used when Prof Bob can't find a keyword in 
   the user's input.

   The Responder object gets a vague response by calling 
   respond(), which serves up a sentence at semi-random; 
   semi-random because the sentence will not be the same as 
   the one returned by the previous call to respond().
*/

import java.util.*;
import java.io.*;


public class VagueResponses
{
  private ArrayList vagueResps;     // ArrayList of responses

  // used in the semi-random selection of a response
  private Random rand;
  private int previousRandInt;


  public VagueResponses(String fnm)
  {
    vagueResps = new ArrayList();
    rand = new Random();
    previousRandInt = -1;

    loadVaguesFile(fnm);
    System.out.println("No. of vague responses: " + vagueResps.size());
  } // end of VagueResponses();


  public String respond()
  // return a string chosen at (semi-)random
  { 
    int posn = getRandomInt(vagueResps.size());
    return (String) vagueResps.get(posn);
  }  // end of respond()


  private int getRandomInt(int max)
  // avoid getting the same random integer as last time
  {
     int num = rand.nextInt(max);
     while (num == previousRandInt)
       num = rand.nextInt(max);
     previousRandInt = num;  // store the number for next time
     return num;
  } // end of getRandomInt()


  // ----------- load the  vague responses information -------------------

  private void loadVaguesFile(String fnm)
  /* Load a series of lines from fnm, ignoring blank lines and
     lines starting with "//" (i.e. comment lines). Each line
     of text is added to the vagueResps ArrayList
  */
  { 
    System.out.println("Reading vague responses file: " + fnm);
    try {
      BufferedReader br = new BufferedReader( new FileReader(fnm));
      String line, resp;
      while((line = br.readLine()) != null) {
        if (line.length() == 0)       // ignore a blank line
          continue;
        if (line.startsWith("//"))   // ignore a comment line
          continue;

        // must be a line containing a vague response
        resp = line.trim();
        if (!resp.equals(""))
          vagueResps.add(resp);   // store it
      }
      br.close();
    } 
    catch (IOException e) 
    { System.out.println("Error reading file: " + fnm);
      System.exit(1);
    }
  }  // end of loadVaguesFile()


} // end of VagueResponses class

